import sys

from PyQt5 import QtWidgets
# from PyQt5 import QtCore

# import sys
import os
# import time
# from random import randint

sys.path.insert(0, os.path.abspath("."))

from appteka.pyqt import testing
from appteka.pyqtgraph.waveform import Waveform, MultiWaveform


class TestWaveform(testing.TestDialog):
    """Test suite for Waveform widget."""
    def __init__(self):
        super().__init__()
        self.resize(600, 600)

    def test_just_visible(self):
        w = Waveform()
        self.set_widget(w)
        text = "- Widget is visible"
        self.set_text(text)

    def test_xlabel(self):
        w = Waveform(self, "Time [sec]")
        self.set_widget(w)
        text = "- x label is 'Time [sec]'"
        self.set_text(text)

    def test_time_axis_false(self):
        w = Waveform(self, time_axis=False)
        self.set_widget(w)
        w.update_data([0, 1, 2, 3], [1, 2, 1, 2])
        text = "- x values are usual numbers from 0 to 3"
        self.set_text(text)

    def test_time_axis_true(self):
        w = Waveform(self, time_axis=True)
        self.set_widget(w)
        w.update_data([0, 1, 2, 3], [1, 2, 1, 2])
        text = "- x values are time values"
        self.set_text(text)


class TestMultiWaveform(testing.TestDialog):
    """Test case for MultiWaveform widget."""
    def __init__(self):
        super().__init__()
        self.resize(600, 600)

    def test_top_axis(self):
        # Given multiwaveform
        w = MultiWaveform(self)
        self.set_widget(w)

        # When add plot
        w.add_plot('a', title='plot A')

        # Then there is top axis
        text = "- there is top axis"
        self.set_text(text)


if __name__ == "__main__":
    app = QtWidgets.QApplication(sys.argv)
    TestWaveform().run()
    TestMultiWaveform().run()
    sys.exit(app.exec())



import sys

from PyQt5 import QtWidgets
from PyQt5 import QtCore

import sys
import os
import time
from random import randint

sys.path.insert(0, os.path.abspath("."))

from appteka.pyqt import gui, testing
from appteka.pyqtgraph import phasor


class TestPhasor(testing.TestDialog):
    def test_just_visible(self):
        self.set_widget(phasor.PhasorDiagram())
        self.set_text("Widget is visible")
        text = "- Widget is visible\n"
        text += "- Widget seems to be OK"
        self.set_text(text)

    def test_radius_labels(self):
        d = phasor.PhasorDiagram()
        self.set_widget(d)
        text = "Widget seems to be OK"
        self.set_text(text)

    def test_range_is_two(self):
        d = phasor.PhasorDiagram()
        self.set_widget(d)
        d.set_range(2)
        text = "- Grid is OK\n"
        text += "- The max circle in grid has radius of 2"
        self.set_text(text)

    def test_change_range(self):
        d = phasor.PhasorDiagram()
        self.set_widget(d)
        d.set_range(2)
        d.set_range(4)
        text = "- Grid is OK\n"
        text += "- The max circle in grid has radius of 4"
        self.set_text(text)

    def test_add_phasor(self):
        d = phasor.PhasorDiagram()
        self.set_widget(d)
        d.set_range(100)
        d.add_phasor('ph-1', 80, 1)
        text = "- There is a phasor in first quadrant\n"
        text += "- The color of phasor is white"
        self.set_text(text)

    def test_update_phasor(self):
        d = phasor.PhasorDiagram()
        self.set_widget(d)
        d.set_range(100)
        d.add_phasor('ph-1', 80, 1)
        d.update_phasor('ph-1', 80, 2)
        text = "- There is a phasor in second quadrant\n"
        text += "- Phasor in single"
        self.set_text(text)

    def test_phasor_color(self):
        d = phasor.PhasorDiagram()
        self.set_widget(d)
        d.set_range(100)
        d.add_phasor('ph-1', 80, 1, (255, 0, 0))
        text = "There is a red phasor in first quadrant"
        self.set_text(text)

    def test_three_phasors(self):
        d = phasor.PhasorDiagram()
        self.set_widget(d)
        d.set_range(100)
        d.add_phasor('ph-1', 80, 0, (255, 0, 0))
        d.add_phasor('ph-2', 80, 2 * 3.1415 / 3, (0, 255, 0))
        d.add_phasor('ph-3', 80, -2 * 3.1415 / 3, (0, 0, 255))
        text = "- There are 3 phasors: red, green and blue\n"
        text += "- About 120 degrees between every two phasors"
        self.set_text(text)

    def test_three_phasors_rotated(self):
        d = phasor.PhasorDiagram()
        self.set_widget(d)
        d.set_range(100)
        d.add_phasor('ph-1', 80, 0, (255, 0, 0))
        d.add_phasor('ph-2', 80, 2 * 3.1415 / 3, (0, 255, 0))
        d.add_phasor('ph-3', 80, -2 * 3.1415 / 3, (0, 0, 255))
        d.update_phasor('ph-1', 80, 1)
        d.update_phasor('ph-2', 80, 1 + 2 * 3.1415 / 3)
        d.update_phasor('ph-3', 80, 1 - 2 * 3.1415 / 3)
        text = "- There are 3 phasors: red, green and blue\n"
        text += "- About 120 degrees between every two phasors\n"
        text += "- Red phasor has angle about 1 radian"
        self.set_text(text)

    def test_range_to_phasor(self):
        d = phasor.PhasorDiagram()
        self.set_widget(d)
        d.add_phasor('ph-1', color=(255, 255, 0))
        d.update_phasor('ph-1', 1, 1)
        d.update_phasor('ph-1', 100, 1)
        d.set_range(100)
        text = "Grid corresponds to phasor"
        self.set_text(text)

    def test_legend(self):
        d = phasor.PhasorDiagram()
        self.set_widget(d)
        d.add_phasor('ph-1', 80, 0, (255, 0, 0))
        d.add_phasor('ph-2', 80, 2 * 3.1415 / 3, (0, 255, 0))
        d.add_phasor('ph-3', 80, -2 * 3.1415 / 3, (0, 0, 255))
        d.show_legend()
        d.set_range(80)
        text = "Legend is correct"
        self.set_text(text)

    def test_three_phasors_animation(self):
        d = phasor.PhasorDiagram()
        self.set_widget(d)
        d.add_phasor('ph-1', color=(255, 0, 0))
        d.add_phasor('ph-2', color=(0, 255, 0))
        d.add_phasor('ph-3', color=(0, 0, 255))
        d.show_legend()

        self.timer = QtCore.QTimer(self)
        self.timer.setInterval(10)

        self.step = 0

        def rotate():
            a = 2 * 3.1415 / 3
            sh = self.step / 200
            ash = self.step / 10
            d.update_phasor('ph-1', ash + 10, sh)
            d.update_phasor('ph-2', 10, sh + a)
            d.update_phasor('ph-3', 10, sh - a)
            d.set_range(ash + 10)

            self.step += 1
            if self.step > 100:
                self.timer.stop()
                self.enable_buttons()

        self.timer.timeout.connect(rotate)
        self.timer.start()
        self.disable_buttons()

        text = "- Phasors smoothly rotating\n"
        text += "- Amplitude of red phasor grows"
        self.set_text(text)


if __name__ == "__main__":
    app = QtWidgets.QApplication(sys.argv)
    d = TestPhasor()
    d.run()
    sys.exit(app.exec())



import sys
import os

from PyQt5 import QtWidgets

sys.path.insert(0, os.path.abspath("."))
from appteka.pyqt import testing
from appteka.pyqt.codetextedit import CodeTextEdit


class TestCodeTextEdit(testing.TestDialog):
    """Tests for CodeTextEdit"""
    def __init__(self):
        super().__init__()
        self.resize(600, 600)

    def test_text(self):
        e = CodeTextEdit()
        self.set_widget(e)

        code = ""
        code += '{\n'
        code += '  "a": 1,\n'
        code += '  "b": 2\n'
        code += '}'

        e.set_text(code)
        text = ""
        text += "- Some text is printed\n"
        text += "- Lines numbered\n"
        text += "- Current line is highlighted\n"
        text += "- Font is monospace"
        self.set_text(text)


if __name__ == "__main__":
    app = QtWidgets.QApplication(sys.argv)
    d = TestCodeTextEdit()
    d.run()
    sys.exit(app.exec())



# appteka - helpers collection

# Copyright (C) 2018-2019 Aleksandr Popov

# This program is free software: you can redistribute it and/or modify
# it under the terms of the Lesser GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.

# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# Lesser GNU General Public License for more details.

# You should have received a copy of the Lesser GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

"""This module implements the base class for routines."""


class Routine:
    """Base routine class."""
    def __init__(self):
        self.progress_hook = lambda x: True
        self.finished_hook = lambda: True
        self.volume = 1
        self.ready = 0

    def add_progress(self, part):
        """Add part value to progress."""
        self.ready += part
        self.progress_hook(int(100*self.ready/self.volume))

    def __call__(self):
        raise NotImplementedError
